@@ -1,5 +1,5 @@
 import pytest
-import time
+from datetime import datetime
 from unittest.mock import patch, call
 import os
 import subprocess
